==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/fr/manage.php <==
<?php
return array (
  '-' => '-',
  '<strong>Create</strong> Space' => '<strong>Créer</strong> un nouvel espace',
  '<strong>Manage</strong> members' => '<strong>Gérer</strong> les membres',
  '<strong>Members</strong>' => '<strong>Membres</strong>',
  '<strong>Security</strong> settings' => 'Paramètres de <strong>sécurité</strong>',
  '<strong>Space</strong> Modules' => 'Gestion des <strong>modules</strong>',
  '<strong>Space</strong> settings' => 'Paramètres de cet <strong>espace</strong>',
  'Actions' => 'Actions',
  'Activate' => 'Activer',
  'Add <strong>Modules</strong>' => 'Ajouter des <strong>modules</strong>',
  'Advanced access settings' => 'Paramètres d\'accès avancés',
  'Archive' => 'Archiver',
  'Are you sure you want to remove this member.' => 'Etes vous sur de vouloir retirer ce membre.',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Êtes-vous certain de vouloir supprimer cet espace ? Tout le contenu publié sera définitivement supprimé également !',
  'As owner of this space you can transfer this role to another administrator in space.' => 'En tant que propriétaire de cet espace, vous pouvez transférer ce rôle à un administrateur de cet espace.',
  'Cancel Membership' => 'Annuler l\'adhésion',
  'Choose if new content should be public or private by default' => 'Choisir si les nouveaux contenus doivent être publics ou privés par défaut',
  'Choose the kind of membership you want to provide for this workspace.' => 'Choisissez le type de participation à cet espace.',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => 'Choisissez les modules que vous souhaitez utiliser dans cet Espace. Vous pourrez également les activer plus tard dans les réglages de l’Espace.',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => 'Choisissez les modules que vous souhaitez utiliser dans cet Espace. Pour que les modules puissent apparaître ici, ils doivent d’abord avoir été installés par un administrateur ou une administratrice du réseau via le panneau d’administration. Si vous ne pouvez pas désactiver certains modules, c’est qu’ils ont été définis comme modules par défaut pour le réseau entier.',
  'Choose the security level for this workspace to define the visibleness.' => 'Choisissez le niveau de sécurité de cet espace pour en définir la visibilité.',
  'Currently there are no modules available for this space!' => 'Aucun module n\'est disponible actuellement pour cet espace.',
  'Delete' => 'Effacer',
  'Don\'t receive notifications for new content' => 'Ne pas recevoir de notification pour chaque nouvelle publication',
  'Hide posts on dashboard' => 'Ne pas afficher les publications de cet espace sur le fil d\'actualités',
  'Invited By' => 'Invité par',
  'Members' => 'Membres',
  'Modules' => 'Modules',
  'Next' => 'Suivant',
  'Owner' => 'Propriétaire',
  'Pending Approvals' => 'Demandes en attente',
  'Pending Invites' => 'Invitations en attente',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Les permissions sont affectées à différents rôles-utilisateur. Pour modifier une permission, sélectionner le rôle-utilisateur que vous voulez modifier et changer la valeur souhaitée dans la liste déroulante des permissions.',
  'Please type the name of the space to proceed.' => 'Veuillez entrer le nom de l\'espace pour continuer.',
  'Receive Notifications for new content' => 'Recevoir une notification pour chaque nouvelle publication',
  'Remove from space' => 'Retirer de cet espace',
  'Role' => 'Rôle',
  'Security' => 'Sécurité',
  'Show all' => 'Afficher tout',
  'Show posts on dashboard' => 'Afficher les publications de cet espace sur le fil d\'actualités',
  'Space name' => 'Nom de cet espace',
  'Space owner' => 'Propriétaire de cet espace',
  'Stream (Default)' => 'Fil d\'actualités (par défaut)',
  'The url contains illegal characters!' => 'L\'URL introduite contient des caractères interdits.',
  'This option will hide new content from this space at your dashboard' => 'Masquer les publications de cet espace sur votre fil d\'actualités',
  'This option will show new content from this space at your dashboard' => 'Afficher les publications de cet espace sur votre fil d\'actualités',
  'Transfer ownership' => 'Changer de propriétaire',
  'Unarchive' => 'Désarchiver',
  'e.g. example for {baseUrl}/s/example' => 'p.ex. pour {baseUrl}/s/exemple',
  'never' => 'jamais',
  'the default start page of this space for members' => 'la page par défaut de cet espace pour les membres',
  'the default start page of this space for visitors' => 'la page par défaut de cet espace pour les visiteurs',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/fr/manage.php <==
<?php
return array (
  '-' => '-',
  '<strong>Create</strong> Space' => '<strong>Créer</strong> un nouvel espace',
  '<strong>Manage</strong> members' => '<strong>Gérer</strong> les membres',
  '<strong>Members</strong>' => '<strong>Membres</strong>',
  '<strong>Security</strong> settings' => 'Paramètres de <strong>sécurité</strong>',
  '<strong>Space</strong> Modules' => 'Gestion des <strong>modules</strong>',
  '<strong>Space</strong> settings' => 'Paramètres de cet <strong>espace</strong>',
  'Actions' => 'Actions',
  'Activate' => 'Activer',
  'Add <strong>Modules</strong>' => 'Ajouter des <strong>modules</strong>',
  'Advanced access settings' => 'Paramètres d\'accès avancés',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => 'Tous les membres de cet Espace seront retirés à l’exception des modérateurs, modératrices, administrateurs et administratrices. Toutes les invitations et demandes d’adhésion en attente seront annulées.',
  'Archive' => 'Archiver',
  'Are you sure you want to remove this member.' => 'Etes vous sur de vouloir retirer ce membre.',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Êtes-vous certain de vouloir supprimer cet espace ? Tout le contenu publié sera définitivement supprimé également !',
  'As owner of this space you can transfer this role to another administrator in space.' => 'En tant que propriétaire de cet espace, vous pouvez transférer ce rôle à un administrateur de cet espace.',
  'Cancel Membership' => 'Annuler l\'adhésion',
  'Choose if new content should be public or private by default' => 'Choisir si les nouveaux contenus doivent être publics ou privés par défaut',
  'Choose the kind of membership you want to provide for this workspace.' => 'Choisissez le type de participation à cet espace.',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => 'Choisissez les modules que vous souhaitez utiliser dans cet Espace. Vous pourrez également les activer plus tard dans les réglages de l’Espace.',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => 'Choisissez les modules que vous souhaitez utiliser dans cet Espace. Pour que les modules puissent apparaître ici, ils doivent d’abord avoir été installés par un administrateur ou une administratrice du réseau via le panneau d’administration. Si vous ne pouvez pas désactiver certains modules, c’est qu’ils ont été définis comme modules par défaut pour le réseau entier.',
  'Choose the security level for this workspace to define the visibleness.' => 'Choisissez le niveau de sécurité de cet espace pour en définir la visibilité.',
  'Currently there are no modules available for this space!' => 'Aucun module n\'est disponible actuellement pour cet espace.',
  'Delete' => 'Effacer',
  'Don\'t receive notifications for new content' => 'Ne pas recevoir de notification pour chaque nouvelle publication',
  'Hide posts on dashboard' => 'Ne pas afficher les publications de cet espace sur la vue d\'ensemble',
  'Invited By' => 'Invité par',
  'Members' => 'Membres',
  'Modules' => 'Modules',
  'Next' => 'Suivant',
  'Owner' => 'Propriétaire',
  'Pending Approvals' => 'Demandes en attente',
  'Pending Invites' => 'Invitations en attente',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Les permissions sont affectées à différents rôles-utilisateur. Pour modifier une permission, sélectionner le rôle-utilisateur que vous voulez modifier et changer la valeur souhaitée dans la liste déroulante des permissions.',
  'Please type the name of the space to proceed.' => 'Veuillez entrer le nom de l\'espace pour continuer.',
  'Receive Notifications for new content' => 'Recevoir une notification pour chaque nouvelle publication',
  'Removal of members queued' => 'Retrait des membres dans la file d’attente',
  'Remove all members' => 'Retirer tous les membres',
  'Remove from space' => 'Retirer de cet espace',
  'Role' => 'Rôle',
  'Security' => 'Sécurité',
  'Show all' => 'Afficher tout',
  'Show posts on dashboard' => 'Afficher les publications de cet espace sur la vue d\'ensemble',
  'Space name' => 'Nom de cet espace',
  'Space owner' => 'Propriétaire de cet espace',
  'Stream (Default)' => 'Fil d\'actualités (par défaut)',
  'The URL has already been taken.' => '',
  'The url contains illegal characters!' => 'L\'URL introduite contient des caractères interdits.',
  'This option will hide new content from this space at your dashboard' => 'Masquer les publications de cet espace sur votre vue d\'ensemble',
  'This option will show new content from this space at your dashboard' => 'Afficher les publications de cet espace sur votre vue d\'ensemble',
  'Transfer ownership' => 'Changer de propriétaire',
  'Unarchive' => 'Désarchiver',
  'e.g. example for {baseUrl}/s/example' => 'p.ex. pour {baseUrl}/s/exemple',
  'never' => 'jamais',
  'the default start page of this space for members' => 'la page par défaut de cet espace pour les membres',
  'the default start page of this space for visitors' => 'la page par défaut de cet espace pour les visiteurs',
);
